Learn R Programming

pacheck (version 0.2.2)

calculate_nb: Calculate NMB and NHB for two strategies.

Description

This function calculates the Net Monetary Benefits (NMB) and Net Health Benefits (NHB) for each strategy and the incremental NMB and NHB.

Usage

calculate_nb(df, e_int, e_comp, c_int, c_comp, wtp)

Value

A dataframe containing the original data and the following variables:

  • NMB_int = Net monetary benefit of the intervention

  • NMB_comp = Net monetary benefit of the comparator

  • iNMB = Incremental net monetary benefit of the intervention versus the comparator

  • NHB_int = Net health benefit of the intervention

  • NHB_comp = Net health benefit of the comparator

  • iNHB = Net health benefit of the intervention versus the comparator

Arguments

df

a dataframe.

e_int

character. Name of variable of the dataframe containing total effects of the intervention strategy.

e_comp

character. Name of variable of the dataframe containing total effects of the comparator strategy.

c_int

character. Name of variable of the dataframe containing total costs of the intervention strategy.

c_comp

character. Name of variable of the dataframe containing total costs of the comparator strategy.

wtp

numeric. Willingness-to-pay thresholds to use for NMB and NHB calculations.

Examples

Run this code
# Calculate NB's at a willingness-to-pay threshold of 80000 per unit of effects
data("df_pa")
calculate_nb(df = df_pa,
             e_int = "t_qaly_d_int",
             e_comp = "t_qaly_d_comp",
             c_int = "t_costs_d_int",
             c_comp = "t_costs_d_comp",
             wtp = 80000)

Run the code above in your browser using DataLab