- df
a dataframe.
- y_var
character. Name of the output variable in the dataframe. This will be the dependent variable of the metamodel.
- x_vars
character or a vector for characters. Name of the input variable(s) in the dataframe. This will be the independent variable of the metamodel.
- seed_num
numeric. Determine which seed number to use to split the dataframe in fitting an validation sets.
- standardise
logical. Determine whether the parameter of the linear regression should be standardised. Default is FALSE.
- tune_plot
logical. Determine whether the plot of the results of tuning the lambda should be shown.
- x_poly_2
character. character or a vector for characters. Name of the input variable in the dataframe. These variables will be exponentiated by factor 2.
- x_poly_3
character. character or a vector for characters. Name of the input variable in the dataframe. These variables will be exponentiated by factor 3.
- x_exp
character. character or a vector for characters. Name of the input variable in the dataframe. The exponential of these variables will be included in the metamodel.
- x_log
character. character or a vector for characters. Name of the input variable in the dataframe. The logarithm of these variables will be included in the metamodel.
- x_inter
character. character or a vector for characters. Name of the input variables in the dataframe. This vector contains the variables for which the interaction should be considered. The interaction terms of two consecutive variables will be considered in the linear model; hence, the length of this vector should be even.