df_ckd_results: A dataframe containing probabilistic outputs for testing
Description
A dataframe containing 1,000 sets of probabilistic outputs from a health state transition model developed in Python for individuals aged 35, screened every 10 years, versus no screening.
Usage
df_ckd_results
Arguments
Format
The dataframe contains the 1,000 probabilistic outputs from the CKD Screening CEA health economic model.