df_iviRA_pa: Dataframe of inputs and outputs of a health economic model developed and evaluated with the iviRA R package for testing
Description
A dataframe containing 1,000 sets of probabilistic inputs and outputs of a individual-level health state transition model developed using iviRA package available on Github.
Usage
df_iviRA_pa
Arguments
Format
See the documentation of the `sample_pars` function of the iviRA package for details.