Learn R Programming

pacheck (version 0.2.2)

do_discount_check: Perform discounted and undiscounted results check

Description

This function performs multiple checks on user-defined columns.

Usage

do_discount_check(df, v_outcomes = NULL, v_outcomes_d = NULL)

Value

A matrix.

Arguments

df

a dataframe.

v_outcomes

(a vector of) character. Name of the variables containing undiscounted outcomes of the model.

v_outcomes_d

(a vector of) character. Name of the variables containing discounted outcomes of the model.

Details

The variables contained in `v_outcomes` and `v_outcomes_d` should be in the same order.

Examples

Run this code
# Checking whether discounted QALYs are lower than undiscounted QALYs using the example data
do_discount_check(df = df_pa,
                  v_outcomes = "t_qaly_comp",
                  v_outcomes_d = "t_qaly_d_comp")
                  

Run the code above in your browser using DataLab